# mirascope.core.litellm.call

!!! note "See OpenAI For Full Reference"

    We use the types found in the [`openai`](../openai/call.md) module for our LiteLLM integration, so please reference that module for information regarding anything beyond the LiteLLM `call` decorator.

::: mirascope.core.litellm.call
